@@ -97,6 +97,7 @@ class Event:
                         if isinstance(body, bytes):
                             ret = json.loads(str(body, encoding='utf-8'))
                         if ret['state'] == 200:
+                            logging.info("handle(%s) register SUCCESS" % k)
                             handleId = ret['msg']['id']
                             if 'trigger' in config:
                                 self._triggerRegister(
@@ -125,6 +126,9 @@ class Event:
                 if state != 200:
                     logging.error('%s register trigger %s failed. %s' % (
                         handle, trigger_config['section'], body))
+                else:
+                    logging.info('%s register trigger %s success.' % (
+                        handle, trigger_config['section']))
         except Exception as e:
             logging.error('%s register trigger error. %s' % (handle, e))
 
