@@ -17,9 +17,9 @@ class RPCRegister:
         self._sc_uri = rpcConfig['uri']
 
     def RegisterRPC(self):
-        self._registerService()
-    
-    def RegisterMethod(self, pk ,serviceClass):
+        return self._registerService()
+
+    def RegisterMethod(self, pk, serviceClass):
         self._registerMehotd(pk, serviceClass)
 
     def _registerService(self):
@@ -41,7 +41,8 @@ class RPCRegister:
             ret = str(ret, encoding='utf-8')
             ret = json.loads(ret, encoding='utf-8')
             if ret["state"] == 200:
-                logging.info("%s(%s) register success."%(self._serviceConfig['key'],self._serviceConfig['name']))
+                logging.info("%s(%s) register success." % (
+                    self._serviceConfig['key'], self._serviceConfig['name']))
                 if ret["msg"]["id"]:
                     self._registerHost(ret["msg"]["id"], self._hostConfig)
                     #self._registerMehotd(ret["msg"]["id"], serviceClass)
@@ -81,31 +82,40 @@ class RPCRegister:
                         'state'], ret['msg'])
                     logging.error(m_msg)
                 else:
-                    logging.info("%s register service hosts(%s:%s) success." % (
+                    logging.info("register service hosts(%s:%s) success." % (
                         hosts[i]['host'], hosts[i]["port"]))
 
     def _registerMehotd(self, pk, serviceClass):
         # 注册方法
-        for k,v in serviceClass.__dict__.items():
-            if isinstance(v,FunctionType):
-                func_name= v.__name__.upper()
+        for k, v in serviceClass.__dict__.items():
+            if isinstance(v, FunctionType):
+                func_name = v.__name__.upper()
                 if v.__doc__:
-                    methods= doc(v.__doc__,"rpc")
+                    methods = doc(v.__doc__, "rpc")
                     if methods:
-                        methods= methods.replace("\n","").strip()
+                        methods = methods.replace("\n", "").strip()
                         try:
-                            methods= [json.loads(methods, encoding='utf-8')]
+                            methods = [json.loads(methods, encoding='utf-8')]
                             for i in range(0, len(methods)):
                                 # todo register method.
                                 methods[i]['service'] = pk
                                 if not 'key' in methods[i]:
-                                    methods[i]['key']= self._serviceConfig['key'].upper()+"_"+serviceClass.__name__.upper()+"_" +func_name
+                                    methods[i]['key'] = self._serviceConfig['key'].upper(
+                                    )+"."+serviceClass.__name__.upper()+"_" + func_name
                                 else:
                                     if not methods[i]['key']:
-                                        methods[i]['key']= self._serviceConfig['key'].upper()+"_"+serviceClass.__name__.upper()+"_" +func_name
+                                        methods[i]['key'] = self._serviceConfig['key'].upper(
+                                        )+"."+serviceClass.__name__.upper()+"_" + func_name
+                                    else:
+                                        if len(methods[i]['key'].split('.')) == 1:
+                                            methods[i]['key'] = self._serviceConfig['key'].upper(
+                                            )+"."+serviceClass.__name__.upper()+"_" + methods[i]['key']
+                                        else:
+                                            logging.error(
+                                                "%s key can not contain (.) ." % methods[i]['key'])
                                 m_service_uri_post_data = ''
                                 if not methods[i]['uri'].endswith('/'):
-                                    methods[i]['uri']+= '/'
+                                    methods[i]['uri'] += '/'
                                 m_count = 0
                                 for k, v in methods[i].items():
                                     if k.lower() != 'params':
@@ -138,15 +148,18 @@ class RPCRegister:
                                 state, ret = POST(self._sc_uri+"uri/", post_data=bytes(
                                     m_service_uri_post_data, encoding='utf8'), http_headers=self._m_heads, time_out=15)
                                 if state != 200:
-                                    logging.error('register service methods failed. msg:{}' % str(ret, encoding='utf-8'))
+                                    logging.error('register service methods failed. msg:{}' % str(
+                                        ret, encoding='utf-8'))
                                 else:
-                                    ret = json.loads(str(ret, encoding='utf-8'))
+                                    ret = json.loads(
+                                        str(ret, encoding='utf-8'))
                                     if ret['state'] != 200:
                                         m_msg = 'register service methods failed. http code(%d), msg:%s' % (
                                             ret['state'], ret['msg'])
                                         logging.error(m_msg)
                                     else:
-                                        logging.info("%s register success."%methods[i]['key'])
+                                        logging.info(
+                                            "%s register success." % methods[i]['key'])
                                         if ret:
                                             if 'params' in methods[i]:
                                                 params = methods[i]['params']
@@ -163,7 +176,8 @@ class RPCRegister:
                                                                     'methods params (%s) is none.' % k.lower())
                                                             m_service_method_params_post_data += k + \
                                                                 "=" + \
-                                                                parse.quote(str(v))
+                                                                parse.quote(
+                                                                    str(v))
                                                             m_count += 1
                                                             try:
                                                                 if m_count < len(params[param_offset]):
@@ -183,7 +197,9 @@ class RPCRegister:
                                                     for k, v in m_returns.items():
                                                         if k.lower() != 'descriptions':
                                                             reg_returns_params += k + \
-                                                                "="+parse.quote(str(v))
+                                                                "=" + \
+                                                                parse.quote(
+                                                                    str(v))
                                                             m_count += 1
                                                             if 'descriptions' in m_returns:
                                                                 if m_count < len(m_returns)-1:
@@ -199,7 +215,8 @@ class RPCRegister:
                                                         if ret['state'] != 200:
                                                             m_msg = 'register service methods failed. http code(%d), msg:%s' % (
                                                                 ret['state'], ret['msg'])
-                                                            logging.error(m_msg)
+                                                            logging.error(
+                                                                m_msg)
                                                         else:
                                                             m_returns_id = ret['msg']['id']
                                                             if 'descriptions' in m_returns:
@@ -224,14 +241,16 @@ class RPCRegister:
                                                                         m_returns_description, encoding='utf-8'), http_headers=self._m_heads, time_out=15)
                                                                     if state != 200:
                                                                         m_msg = 'register return description failed. http code(%d)' % state
-                                                                        logging.error(m_msg)
+                                                                        logging.error(
+                                                                            m_msg)
                                                                     else:
                                                                         ret = json.loads(
                                                                             str(ret, encoding='utf-8'))
                                                                         if ret['state'] != 200:
                                                                             m_msg = 'register return description failed. state(%d), msg(%s), key()' % (
                                                                                 ret['state'], ret['msg'], item['key'])
-                                                                            logging.error(m_msg)
+                                                                            logging.error(
+                                                                                m_msg)
                                                     else:
                                                         m_msg = 'register returns failed. http code(%d)' % state
                                                         logging.error(m_msg)
@@ -243,7 +262,9 @@ class RPCRegister:
                                                 logging.error(m_msg)
                         except Exception as e:
                             logging.error(e)
-                            logging.error("register params error. method config error.please checked %s.__doc__"%(v.__name__))
+                            logging.error(
+                                "register params error. method config error.please checked %s.__doc__" % (v.__name__))
+
 
 class RPC:
     '''
@@ -278,7 +299,7 @@ class RPC:
     def _getApi(self, service, method):
         if service+method not in self._apisTable:
             # 远程获取
-
+            method = parse.quote(method)
             status, body = GET(uri=self._sc_uri+"rpc/?key="+service +
                                "&method="+method, time_out=15, http_headers=self._m_heads)
             if status == 200:
@@ -550,9 +571,9 @@ class RPC:
                             str(kwargs[param['key']])))
                 if m_method == u"GET" or m_method == u"DELETE":
                     if m_uri.find('?'):
-                        m_uri+="&"+ params_data
+                        m_uri += "&" + params_data
                     else:
-                        m_uri+="?"+params_data
+                        m_uri += "?"+params_data
                 try:
                     if m_method == u"GET":
                         self._log(m_uri)
